@@ -35,9 +35,9 @@ class SALICONDataset(Dataset):
 
         # for albumentations only!
         if self.transform:
-            output = self.transform(image=img, saliency=target)
+            output = self.transform(image=img, mask=target)
             img = output['image']
-            target = output['saliency']
+            target = output['mask']
         return img, target
 
     def __len__(self):
